@@ -1,14 +1,8 @@
 """Functions and utils for managing the global mmcore singleton."""
 from __future__ import annotations
 
-import re
-from typing import Iterator
-
 from pymmcore_plus import CMMCorePlus
 
-MAG_PATTERN = re.compile(r"(\d{1,3})[xX]")
-RESOLUTION_ID_PREFIX = "px_size_"
-
 
 def load_system_config(config: str = "", mmcore: CMMCorePlus | None = None) -> None:
     """Internal convenience for `loadSystemConfiguration(config)`.
@@ -22,11 +16,3 @@ def load_system_config(config: str = "", mmcore: CMMCorePlus | None = None) -> N
     mmc = mmcore or CMMCorePlus.instance()
     mmc.unloadAllDevices()
     mmc.loadSystemConfiguration(config or "MMConfig_demo.cfg")
-
-
-def iter_dev_props(mmc: CMMCorePlus | None = None) -> Iterator[tuple[str, str]]:
-    """Yield all pairs of currently loaded (device_label, property_name)."""
-    mmc = mmc or CMMCorePlus.instance()
-    for dev in mmc.getLoadedDevices():
-        for prop in mmc.getDevicePropertyNames(dev):
-            yield dev, prop
