@@ -202,16 +202,22 @@ def test_add_preset(global_mmcore: CMMCorePlus, qtbot: QtBot):
 
     add_prs.preset_name_lineedit.setText("New")
 
-    mode = add_prs.table.cellWidget(3, 1)
-    mode.setValue("Color Test Pattern")
-    wdg = add_prs.table.cellWidget(5, 1)
-    wdg.setValue("Shutter")
+    dapi_values = []
+    for k in mmc.getConfigData("Channel", "DAPI").dict().values():
+        values = list(k.values())
+        if len(values) > 1:
+            dapi_values.extend(iter(values))
+        else:
+            dapi_values.append(values[0])
+
+    for i in range(add_prs.table.rowCount()):
+        add_prs.table.cellWidget(i, 1).setValue(dapi_values[i])
 
     with pytest.warns(UserWarning):
         add_prs.add_preset_button.click()
         assert add_prs.info_lbl.text() == "'DAPI' already has the same properties!"
 
-    mode.setValue("Noise")
+    add_prs.table.cellWidget(3, 1).setValue("Noise")
     add_prs.add_preset_button.click()
     assert add_prs.info_lbl.text() == "'New' has been added!"
 
@@ -225,8 +231,10 @@ def test_add_preset(global_mmcore: CMMCorePlus, qtbot: QtBot):
         ("Camera", "Mode", "Noise"),
         ("Multi Shutter", "Physical Shutter 1", "Undefined"),
         ("Multi Shutter", "Physical Shutter 2", "Shutter"),
-        ("Multi Shutter", "Physical Shutter 3", "Undefined"),
+        ("Multi Shutter", "Physical Shutter 3", "StateDev Shutter"),
         ("Multi Shutter", "Physical Shutter 4", "Undefined"),
+        ("StateDev Shutter", "State Device", "StateDev"),
+        ("StateDev", "Label", "State-1"),
     ]
 
     for r in range(gp.table_wdg.rowCount()):
